#
# spec file for package python-vega
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python39 1
Name:           python-vega
Version:        4.0.0
Release:        4.4
Summary:        An IPython/Jupyter widget for Vega 3 and Vega-Lite 2
License:        BSD-3-Clause
URL:            https://github.com/vega/ipyvega/
Source:         https://files.pythonhosted.org/packages/source/v/vega/vega-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  fdupes
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  python-rpm-macros
Requires:       python-ipytablewidgets >= 0.3.0
Requires:       python-jupyter >= 1.0.0
Requires:       python-pandas >= 1.5.0
Recommends:     python-ipywidgets
Recommends:     python-jupyterlab
Provides:       python-jupyter_vega = %{version}-%{release}
Obsoletes:      python-jupyter_vega < %{version}-%{release}
BuildArch:      noarch
%if "%{python_flavor}" == "python3" || "%{?python_provides}" == "python3"
# notebook >= 5.3 does not need to install a separate nbextension
Provides:       jupyter-vega = %{version}-%{release}
Obsoletes:      jupyter-vega < %{version}-%{release}
%endif
# SECTION test requirements
BuildRequires:  %{python_module ipytablewidgets >= 0.3.0}
BuildRequires:  %{python_module ipywidgets}
BuildRequires:  %{python_module jupyterlab}
BuildRequires:  %{python_module jupyter}
BuildRequires:  %{python_module pandas >= 1.5.0}
BuildRequires:  %{python_module pytest >= 7.2}
# /SECTION
%python_subpackages

%description
IPython/Jupyter notebook module for Vega and Vega-Lite,
Polestar, and Voyager. Notebooks with embedded visualizations
can be viewed on github and nbviewer.

%prep
%setup -q -n vega-%{version}
sed -i s/poetry.masonry/poetry.core.masonry/ pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{_jupyter_prefix}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# altair 5 not compatible with vega
ignoretests="--ignore vega/tests/test_entrypoint.py"
%pytest $ignoretests

%files %{python_files}
%license LICENSE
%exclude %{_bindir}/test
%{python_sitelib}/vega/
%{python_sitelib}/vega-%{version}*-info

%changelog
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Disable altair entrypoint tests: altair 5 removed the vega
  wrappers
  * gh#altair-viz/altair#2829
  * gh#vega/ipyvega#509
* Wed May 31 2023 Ben Greiner <code@bnavigator.de>
- Replace poetry build backend with poetry-core
* Mon May  1 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.0
  * Improve serialization of Pandas DataFrames to ipyvega (#346)
  * Pandas update 1.5 (#463)
  * galata and ipytablewidgets update, other improvements (#464)
* Sat Jul 16 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 3.6.0:
  * Formally define the DOMWidgetModel <-> DOMWidgetView relationship
    (#397)
  * Bump version and use template literals
  * Don't define/require under nbextension prefix
- changes from version 3.5.0:
  * fix: remove data before inserting in widget
  * Consistent widget style
* Fri Feb 19 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build: With NumPy 1.20, Tumbleweed no longer
  provides a python36-pandas (NEP 29)
* Fri Jan 29 2021 Ben Greiner <code@bnavigator.de>
- Build wheel from source
- Remove python-base >= 3.8 requirement
- Merge empty jupyter-vega package into main python package
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.4.0:
  * Add altair endpoints
  * Internal updates
* Wed Mar 11 2020 Todd R <toddrme2178@gmail.com>
- Fix download URL.
* Wed Mar 11 2020 Todd R <toddrme2178@gmail.com>
- Update to 3.1.0
  * Upgrade pandas dependency
  * Bump vega-lite from 4.0.2 to 4.1.1
  * Bump @types/webpack-env from 1.15.0 to 1.15.1
  * Bump webpack from 4.41.5 to 4.41.6
  * Bump vega-lite from 4.1.1 to 4.3.1
  * Bump webpack-cli from 3.3.10 to 3.3.11
  * Bump vega-lite from 4.3.1 to 4.4.0
  * Bump typescript from 3.7.5 to 3.8.2
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 3.0.2
  * Cleaner setup
- Update to 3.0.1
  * remove setup.py
  * Cleanup testing
  * Update to Vega-Lite 4. Use Poetry.
- Update to 3.0.0
  * Upgrade to Vega-Lite 4
  * Bump vega-embed from 6.2.1 to 6.2.2
  * Bump vega from 5.9.0 to 5.9.1
  * Bump typescript from 3.7.4 to 3.7.5
  * Bump @types/webpack-env from 1.14.1 to 1.15.0
  * Bump webpack from 4.41.4 to 4.41.5
  * Bump webpack from 4.41.2 to 4.41.4
  * Bump typescript from 3.7.3 to 3.7.4
  * Bump vega from 5.8.1 to 5.9.0
  * Bump typescript from 3.7.2 to 3.7.3
  * Bump vega-embed from 6.2.0 to 6.2.1
  * Use embed's finalize
  * Bump vega-embed from 6.0.0 to 6.1.0
  * Bump vega from 5.8.0 to 5.8.1
  * Bump vega from 5.7.3 to 5.8.0
  * Upgrade deps
  * Bump @jupyter-widgets/base from 2.0.1 to 2.0.2
  * Bump typescript from 3.6.4 to 3.7.2
  * Bump ts-loader from 6.2.0 to 6.2.1
  * Bump vega-embed from 5.1.3 to 6.0.0
  * Bump webpack from 4.41.1 to 4.41.2
  * Bump vega from 5.7.2 to 5.7.3
  * Bump webpack from 4.41.0 to 4.41.1
  * Bump typescript from 3.6.3 to 3.6.4
  * Bump @types/webpack-env from 1.14.0 to 1.14.1
  * Bump vega from 5.7.0 to 5.7.2
  * Bump vega from 5.6.0 to 5.7.0
  * Bump webpack from 4.40.2 to 4.41.0
  * Bump ts-loader from 6.1.2 to 6.2.0
  * Bump ts-loader from 6.1.0 to 6.1.2
  * Bump vega-embed from 5.1.2 to 5.1.3
  * Bump webpack-cli from 3.3.8 to 3.3.9
  * Bump webpack from 4.39.3 to 4.40.2
  * Bump ts-loader from 6.0.4 to 6.1.0
  * Bump typescript from 3.6.2 to 3.6.3
  * Bump vega from 5.5.3 to 5.6.0
  * Bump webpack-cli from 3.3.7 to 3.3.8
  * Bump vega-embed from 4.2.4 to 5.1.2
  * Bump webpack from 4.39.2 to 4.39.3
  * Bump typescript from 3.5.3 to 3.6.2
  * Bump vega from 5.4.0 to 5.5.3
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.6.0
  * Update deps and rebuild
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.5.0
  * Update deps and rebuild
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.4.0
  * Update typings
  * Update dependencies in package.json as well
  * No need to set default style.
- Update to 2.3.1
  * Ad try catch around widget code
  * Update deps
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.3.0
  * Add implementation of ipython widget
  * Address review comments
  * Fix optional dependencies with webpack
  * Fix typescript style
  * Handle updates before widget is rendered correctly
  * Add lightweight error messaging for updates
  * Add description to notebook
  * Call finalize when replacing the view
  * Fix error in finalize call, rebuild static js
  * Remove from_chart and update docstring accordingly
  * Make TODO comment re validation more self-explanatory
  * Allow to set embedding options
  * Add point how to select between vega / vega-lite
  * remove defaultStyle
  * Ignore notebooks in package
  * Upgrade deps
- Update to 2.2.0
  * Don't set style since Embed has changed the default anyway
  * Upgrade deps
* Wed May 15 2019 Todd R <toddrme2178@gmail.com>
- Add conflicts to jupyter subpackage to more explicitly handle
  file overlaps with old naming scheme.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.1.0
  * Rebuild bundles
  * Upgrade dependencies
  * Use prettier check
  * Update Vega-Embed
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 1.4.0
  * Simplify js template
  * Display via single mime-bundle without side effects
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 1.3.0
  * export vegaEmbed interface for use on other frontends
- Update to 1.2.0
  * Send same-origin cookies with Vega loader requests.
  * Upgrade deps
* Thu Jun  7 2018 toddrme2178@gmail.com
- Update to 1.1.1
  * BUG: update sanitize_dataframe and tests
  * Upgrade Vega-Embed and other dependencies
- Remove upstream-included update_sanitize_dataframe.patch
* Tue May 29 2018 toddrme2178@gmail.com
- Use || true syntax instead of exit 0
* Thu May 24 2018 toddrme2178@gmail.com
- Added update_sanitize_dataframe.patch
  Fixes compatibility with pandas 0.23
  See: https://github.com/vega/ipyvega/issues/87
  From: https://github.com/vega/ipyvega/pull/88
  Should be in next release
* Fri May 18 2018 jengelh@inai.de
- Avoid [[ ]] and test x==x bashisms.
* Thu May 17 2018 toddrme2178@gmail.com
- Initial version (1.0.1)
